==> nextcloud-27.1.5.tgz: nextcloud/apps/logreader/l10n/de.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Protokollierung",
    "Errors in the log" : "Fehler im Protokoll",
    "No errors in the logs since %s" : "Keine Fehler in den Protokollen seit %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n Fehler in den Protokollen seit %s","%n Fehler in den Protokollen seit %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n Warnungen in den Protokollen seit %s","%n Warnungen in den Protokollen seit %s"],
    "Log Reader" : "Protokoll-Datei-Leser",
    "A log reader for Nextcloud" : "Ein Protokolldatei-Leser für Nextcloud",
    "Log reader for Nextcloud" : "Protokolldatei-Leser für Nextcloud",
    "Log reader" : "Protokolldatei-Leser",
    "Open log reader settings" : "Protokolldatei-Leser-Einstellungen öffnen",
    "Log reader settings" : "Protokolldatei-Leser-Einstellungen",
    "Currently the log file {file} is shown" : "Derzeit wird die Protokolldatei {file} angezeigt.",
    "Show server log" : "Server-Protokoll anzeigen",
    "Live view is disabled" : "Echtzeitanzeige ist deaktiviert.",
    "No log file" : "Keine Protokolldatei",
    "File-based logging must be enabled to access logs from the Web UI." : "Für den Zugriff auf Protokolle über die Web-Benutzeroberfläche muss die dateibasierte Protokollierung aktiviert sein.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Wenn du der Meinung bist, dass dies ein Fehler ist, überprüfe bitte {setting} in deiner {config} und lese das Nextcloud-Administrationshandbuch.",
    "Level" : "Level",
    "App" : "App",
    "No app in context" : "Keine App im Kontext",
    "Time" : "Zeit",
    "Copy raw entry" : "Roheintrag kopieren",
    "Copy formatted entry" : "Formatierten Eintrag kopieren",
    "Hide exception details" : "Ausnahmedetails ausblenden",
    "View exception details" : "Ausnahmedetails anzeigen",
    "Raw log entry" : "Roh-Protokolleintrag",
    "Log entry successfully copied" : "Protokolleintrag erfolgreich kopiert",
    "Search log entries" : "Protokolleinträge suchen",
    "Caused by {exception}" : "Verursacht von {exception}",
    "Line {line}" : "Zeile {line}",
    "Filter log levels" : "Protokollebenen filtern",
    "Set log level" : "Protokollierungsstufe einstellen",
    "Time format" : "Zeitformat",
    "Live view" : "Echtzeitansicht",
    "Download/Upload logs" : "Protokolle herunter-/hochladen",
    "Download logs" : "Protokolldatei herunterladen",
    "Show local log file" : "Lokale Protokolldatei anzeigen",
    "Upload local log file to be displayed" : "Lokale Protokoll-Datei, die angezeigt werden soll, hochladen",
    "Raw data" : "Rohdaten",
    "Local time" : "Lokale Zeit",
    "UTC time" : "UTC-Zeit",
    "Time format used for displaying the timestamp" : "Format für Zeitangaben, das zur Anzeige des Zeitstempels verwendet wird",
    "(Local log files only support the \"raw\" time format)" : "(Lokale Protokolldateien unterstützen nur das „rohe“ Zeitformat).",
    "Could not change date time format." : "Das Format für Datum-Uhrzeit konnte nicht geändert werden.",
    "Polling is disabled because server is not configured to log to file" : "Die Abfrage ist deaktiviert, da der Server nicht für die Protokollierung in einer Datei konfiguriert ist.",
    "Polling (live view)" : "Abfrage (Echtzeitansicht)",
    "Could not change live view setting." : "Einstellungen der Echtzeitansicht konnten nicht geändert werden.",
    "Filter logging levels" : "Protokollierungsebenen filtern",
    "Could not set logging levels to show" : "Anzuzeigende Protokollierungsebenen konnten nicht festgelegt werden.",
    "Set backend loglevel" : "Backend-Protokollierungsstufe festlegen",
    "Could not set logging level" : "Die Protokollierungsstufe konnte nicht festgelegt werden",
    "Application" : "Anwendung",
    "Message" : "Nachricht",
    "Log entry actions" : "Eingabeaktionen protokollieren",
    "Loading older log entries" : "Ältere Protokolleinträge laden",
    "No older log entries available" : "Keine älteren Protokolleinträge vorhanden",
    "Collapse row" : "Zeile zuklappen",
    "Expand row" : "Zeile aufklappen",
    "Show details" : "Details anzeigen",
    "Debug" : "Fehlersuche",
    "Info" : "Information",
    "Warning" : "Warnung",
    "Error" : "Fehler",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Protokolleinträge konnten nicht geladen werden",
    "Could not fetch new log entries (server unavailable)" : "Neue Protokolleinträge konnten nicht abgerufen werden (Server nicht verfügbar).",
    "Could not fetch new entries" : "Neue Einträge konnten nicht abgerufen werden.",
    "Could not copy to clipboard, please copy manually:" : "Konnte nicht in die Zwischenablage kopieren, bitte manuell kopieren:",
    "\tfrom {address} by {user} at {time}\n" : "\tvon {address} von {user} um {time}\n",
    "Error parsing log" : "Fehler beim Verarbeiten der Protokolldatei",
    "Caused by " : "Verursacht durch",
    "Copy" : "Kopieren",
    "Copy raw" : "Rohformat kopieren",
    "Copy formatted" : "Formatiert kopieren",
    "No server logs" : "Keine Server-Log-Dateien",
    "One or more entries are hidden by the log level filter" : "Ein oder mehrere Einträge sind aufgrund des Log-Level-Filter ausgeblendet",
    "Everything is working fine" : "Alles funktioniert gut",
    "Load log file" : "Protokolldatei laden",
    "Invalid log file" : "Ungültige Protokolldatei",
    "Log levels" : "Log-Level",
    "Log content" : "Log-Inhalt",
    "Live update" : "Live-Aktualisierung",
    "line {line}" : "Zeile {line}",
    "Download / Upload logs" : "Protokolle herunter- / hochladen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/logreader/l10n/de.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Protokollierung",
    "Errors in the log" : "Fehler im Protokoll",
    "No errors in the logs since %s" : "Keine Fehler in den Protokollen seit %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n Fehler in den Protokollen seit %s","%n Fehler in den Protokollen seit %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n Warnungen in den Protokollen seit %s","%n Warnungen in den Protokollen seit %s"],
    "Log Reader" : "Protokoll-Datei-Leser",
    "A log reader for Nextcloud" : "Ein Protokolldatei-Leser für Nextcloud",
    "Log reader for Nextcloud" : "Protokolldatei-Leser für Nextcloud",
    "Log reader" : "Protokolldatei-Leser",
    "Open log reader settings" : "Protokolldatei-Leser-Einstellungen öffnen",
    "Log reader settings" : "Protokolldatei-Leser-Einstellungen",
    "Currently the log file {file} is shown" : "Derzeit wird die Protokolldatei {file} angezeigt.",
    "Show server log" : "Server-Protokoll anzeigen",
    "Live view is disabled" : "Echtzeitanzeige ist deaktiviert.",
    "No log file" : "Keine Protokolldatei",
    "File-based logging must be enabled to access logs from the Web UI." : "Für den Zugriff auf Protokolle über die Web-Benutzeroberfläche muss die dateibasierte Protokollierung aktiviert sein.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Wenn du der Meinung bist, dass dies ein Fehler ist, überprüfe bitte {setting} in deiner {config} und lies das Nextcloud-Administrationshandbuch.",
    "Level" : "Level",
    "App" : "App",
    "No app in context" : "Keine App im Kontext",
    "Time" : "Zeit",
    "Copy raw entry" : "Roheintrag kopieren",
    "Copy formatted entry" : "Formatierten Eintrag kopieren",
    "Hide exception details" : "Ausnahmedetails ausblenden",
    "View exception details" : "Ausnahmedetails anzeigen",
    "Raw log entry" : "Roh-Protokolleintrag",
    "Log entry successfully copied" : "Protokolleintrag erfolgreich kopiert",
    "Search log entries" : "Protokolleinträge suchen",
    "Caused by {exception}" : "Verursacht von {exception}",
    "Line {line}" : "Zeile {line}",
    "Filter log levels" : "Protokollebenen filtern",
    "Set log level" : "Protokollierungsstufe einstellen",
    "Time format" : "Zeitformat",
    "Live view" : "Echtzeitansicht",
    "Download/Upload logs" : "Protokolle herunter-/hochladen",
    "Download logs" : "Protokolldatei herunterladen",
    "Show local log file" : "Lokale Protokolldatei anzeigen",
    "Upload local log file to be displayed" : "Lokale Protokoll-Datei, die angezeigt werden soll, hochladen",
    "Ctrl" : "Strg",
    "Raw data" : "Rohdaten",
    "Local time" : "Lokale Zeit",
    "UTC time" : "UTC-Zeit",
    "Time format used for displaying the timestamp" : "Format für Zeitangaben, das zur Anzeige des Zeitstempels verwendet wird",
    "(Local log files only support the \"raw\" time format)" : "(Lokale Protokolldateien unterstützen nur das „rohe“ Zeitformat).",
    "Could not change date time format." : "Das Format für Datum-Uhrzeit konnte nicht geändert werden.",
    "Polling is disabled because server is not configured to log to file" : "Die Abfrage ist deaktiviert, da der Server nicht für die Protokollierung in einer Datei konfiguriert ist.",
    "Polling (live view)" : "Abfrage (Echtzeitansicht)",
    "Could not change live view setting." : "Einstellungen der Echtzeitansicht konnten nicht geändert werden.",
    "Filter logging levels" : "Protokollierungsebenen filtern",
    "Could not set logging levels to show" : "Anzuzeigende Protokollierungsebenen konnten nicht festgelegt werden.",
    "Set backend loglevel" : "Backend-Protokollierungsstufe festlegen",
    "Could not set logging level" : "Die Protokollierungsstufe konnte nicht festgelegt werden",
    "Application" : "Anwendung",
    "Message" : "Nachricht",
    "Log entry actions" : "Eingabeaktionen protokollieren",
    "Loading older log entries" : "Ältere Protokolleinträge laden",
    "No older log entries available" : "Keine älteren Protokolleinträge vorhanden",
    "Collapse row" : "Zeile zuklappen",
    "Expand row" : "Zeile aufklappen",
    "Show details" : "Details anzeigen",
    "Debug" : "Fehlersuche",
    "Info" : "Information",
    "Warning" : "Warnung",
    "Error" : "Fehler",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Protokolleinträge konnten nicht geladen werden",
    "Could not fetch new log entries (server unavailable)" : "Neue Protokolleinträge konnten nicht abgerufen werden (Server nicht verfügbar).",
    "Could not fetch new entries" : "Neue Einträge konnten nicht abgerufen werden.",
    "Could not copy to clipboard, please copy manually:" : "Konnte nicht in die Zwischenablage kopieren, bitte manuell kopieren:",
    "\tfrom {address} by {user} at {time}\n" : "\tvon {address} von {user} um {time}\n",
    "Error parsing log" : "Fehler beim Verarbeiten der Protokolldatei",
    "Caused by " : "Verursacht durch",
    "Copy" : "Kopieren",
    "Copy raw" : "Rohformat kopieren",
    "Copy formatted" : "Formatiert kopieren",
    "No server logs" : "Keine Server-Log-Dateien",
    "One or more entries are hidden by the log level filter" : "Ein oder mehrere Einträge sind aufgrund des Log-Level-Filter ausgeblendet",
    "Everything is working fine" : "Alles funktioniert gut",
    "Load log file" : "Protokolldatei laden",
    "Invalid log file" : "Ungültige Protokolldatei",
    "Log levels" : "Log-Level",
    "Log content" : "Log-Inhalt",
    "Live update" : "Live-Aktualisierung",
    "line {line}" : "Zeile {line}",
    "Download / Upload logs" : "Protokolle herunter- / hochladen"
},
"nplurals=2; plural=(n != 1);");
